/******************************************************
*******************************************************

8th Doctoral Workshop on Big Data and Labour Economics
June 2023

This do file is part of a seminar on Data Management.
It provides a simple demonstration on how to weight EU-LFS micro data,
generating aggregated data.

Raw data files need to be previously imported to dta files.

Author: Javier Garcia-Clemente 
email: javier.garcia@dege.uhu.es
website: https://javier-garcia-clemente.weebly.com

*******************************************************
******************************************************/

clear all
cap log close

* Set working dirs
global from "C:\Users\javga\OneDrive - UNIVERSIDAD DE SEVILLA\ELFS\Dtas" //where data is stored
global to "C:\Users\javga\OneDrive\Escritorio\8thDocWorkshop"	//where results will be stored

* Load dataset (example for yearly wave Spain 2020)
use "$from\ES2020_y.dta"

* Explore data
describe			//all variables
des stapro* 		//my variables of interest

* Identify target (for me: employees in 1st job and self-employed in 2nd)
tab stapro stapro2j 						
tab stapro stapro2j , nolab	

gen byte hybrid = 1 if stapro==3 & stapro2j==0


** Transform weights from thousand to no. of individuals
replace coeff = coeff*1000

* Sum population frequencies for each value 1 and keep the max value
gen hybrid2 = sum(coeff) if hybrid==1
egen hybridmax = max(hybrid2)
list coeff hybrid* if hybrid==1

* Drop unneccesary obs and variables
keep if _n==_N
keep country *max

*** ReName variables and set year
rename *max *
generate int year = 2020	
order year country 

* Check final dataset
list

** Compress and save
compress
save "$to\ES2020_hybrid.dta" , replace


*************************************************************
*********** END
*************************************************************

*************************************************************
****** EXTRA: What if I want to generate hybrids by sex? (e.g.)

* I follow the same structure but now the counter is generated by sex:

clear all
cap log close

* Set working dirs
global from "C:\Users\javga\OneDrive - UNIVERSIDAD DE SEVILLA\ELFS\Dtas" //where data is stored
global to "C:\Users\javga\OneDrive\Escritorio\8thDocWorkshop"	//where results will be stored

* Load dataset (example for yearly wave Spain 2020)
use "$from\ES2020_y.dta"

* Explore data
describe			//all variables
des stapro* 		//my variables of interest

* Identify target (for me: employees in 1st job and self-employed in 2nd)
tab stapro stapro2j 						
tab stapro stapro2j , nolab	

gen byte hybrid = 1 if stapro==3 & stapro2j==0


** Transform weights from thousand to no. of individuals
replace coeff = coeff*1000

*********** Same so far *********

* Sort data by the 'splitting' variable (e.g. sex)
tab sex
sort sex 

* Sum population frequencies for each value 1 and keep the max value
by sex: gen hybrid2 = sum(coeff) if hybrid==1
by sex: egen hybridmax = max(hybrid2)
by sex: list coeff hybrid* if hybrid==1

* Drop unneccesary obs and variables
by sex: keep if _n==_N
keep country sex *max

*** ReName variables and set year
rename *max *
generate int year = 2020	
order year country sex

* Check final dataset
list

** Compress and save
compress
save "$to\ES2020_hybrid_bysex.dta" , replace


********************************************************
********************************************************
* Same program can be 'easily' optimized and looped over multiple target variables and multiple waves, years and countries. Same applies to quarterly data. Appending those resulting files we can obtain aggregate time series or panel data from the micro data

* Just be careful with the low representativeness of the sample when disaggregating too much












